==> qtjambi-webenginecore-6.2.4-sources.jar: io/qt/webengine/core/QWebEngineScriptCollection.java <==
package io.qt.webengine.core;


/**
 * <p>Represents a collection of user scripts</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html">QWebEngineScriptCollection</a></p>
 */
public final class QWebEngineScriptCollection extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#clear">QWebEngineScriptCollection::clear()</a></p>
     */
    @io.qt.QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#contains">QWebEngineScriptCollection::contains(QWebEngineScript)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean contains(io.qt.webengine.core.QWebEngineScript value){
        return contains_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(value));
    }
    
    @io.qt.QtUninvokable
    private native boolean contains_native_cref_QWebEngineScript_constfct(long __this__nativeId, long value);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#count">QWebEngineScriptCollection::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#find">QWebEngineScriptCollection::find(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> find(java.lang.String name){
        return find_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> find_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#insert-1">QWebEngineScriptCollection::insert(QList&lt;QWebEngineScript&gt;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insert(java.util.Collection<io.qt.webengine.core.QWebEngineScript> list){
        insert_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), list);
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QList(long __this__nativeId, java.util.Collection<io.qt.webengine.core.QWebEngineScript> list);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#insert">QWebEngineScriptCollection::insert(QWebEngineScript)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insert(io.qt.webengine.core.QWebEngineScript arg__1){
        insert_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#isEmpty">QWebEngineScriptCollection::isEmpty()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#remove">QWebEngineScriptCollection::remove(QWebEngineScript)</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean remove(io.qt.webengine.core.QWebEngineScript arg__1){
        return remove_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native boolean remove_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#toList">QWebEngineScriptCollection::toList()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> toList(){
        return toList_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> toList_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineScriptCollection(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-webenginecore-6.3.3-sources.jar: io/qt/webengine/core/QWebEngineScriptCollection.java <==
package io.qt.webengine.core;


/**
 * <p>Represents a collection of user scripts</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html">QWebEngineScriptCollection</a></p>
 */
public final class QWebEngineScriptCollection extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#clear">QWebEngineScriptCollection::clear()</a></p>
     */
    @io.qt.QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#contains">QWebEngineScriptCollection::contains(QWebEngineScript)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean contains(io.qt.webengine.core.QWebEngineScript value){
        return contains_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(value));
    }
    
    @io.qt.QtUninvokable
    private native boolean contains_native_cref_QWebEngineScript_constfct(long __this__nativeId, long value);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#count">QWebEngineScriptCollection::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#find">QWebEngineScriptCollection::find(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> find(java.lang.String name){
        return find_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> find_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#insert-1">QWebEngineScriptCollection::insert(QList&lt;QWebEngineScript&gt;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insert(java.util.Collection<? extends io.qt.webengine.core.QWebEngineScript> list){
        insert_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), list);
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.webengine.core.QWebEngineScript> list);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#insert">QWebEngineScriptCollection::insert(QWebEngineScript)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insert(io.qt.webengine.core.QWebEngineScript arg__1){
        insert_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#isEmpty">QWebEngineScriptCollection::isEmpty()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#remove">QWebEngineScriptCollection::remove(QWebEngineScript)</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean remove(io.qt.webengine.core.QWebEngineScript arg__1){
        return remove_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native boolean remove_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginescriptcollection.html#toList">QWebEngineScriptCollection::toList()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> toList(){
        return toList_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineScript> toList_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineScriptCollection(QPrivateConstructor p) { super(p); } 
    
}
